@@ -27,7 +27,7 @@ def load_trigram_file(f):
             l = line.strip().split("\t")
             words = []
             for w in l[0].split(" "):
-                words.append(Orthography.objects.get_or_create(word=w)[0])
+                words.append(Orthography.objects.get_or_create(spelling=w)[0])
             trgs.append(Trigram(word=words[-1],word_i_minus_one=words[1],word_i_minus_two=words[0],count=int(l[1])))
             if len(trgs) > 100000:
                 Trigram.objects.bulk_create(trgs)
